%define url_ver	%(echo %{version}|cut -d. -f1,2)

%global fwupd_version 1.3.3
%global flatpak_version 1.5.1

Summary:	A software center for GNOME
Name:		gnome-software
Version:	3.38.0
Release:	%mkrel 2
License:	GPLv2+
Group:		Graphical desktop/GNOME
URL:		https://wiki.gnome.org/Apps/Software
Source0:	https://download.gnome.org/sources/%{name}/%{url_ver}/%{name}-%{version}.tar.xz
# already upstream
BuildRequires:	gettext
BuildRequires:	xsltproc
BuildRequires:	docbook-style-xsl
BuildRequires:	desktop-file-utils
BuildRequires:	pkgconfig(fwupd) >= %{fwupd_version}
BuildRequires:	pkgconfig(appstream-glib) >= 0.5.11
BuildRequires:	pkgconfig(gio-unix-2.0)
BuildRequires:	pkgconfig(gtk+-3.0) >= 3.9.12
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(libnotify)
BuildRequires:	pkgconfig(packagekit-glib2) >= 1.0.0
BuildRequires:	pkgconfig(libsoup-2.4)
BuildRequires:	pkgconfig(gsettings-desktop-schemas) >= 3.11.4
BuildRequires:	pkgconfig(gnome-desktop-3.0)
BuildRequires:	pkgconfig(malcontent-0)
BuildRequires:	pkgconfig(packagekit-glib2)
BuildRequires:	pkgconfig(polkit-gobject-1)
BuildRequires:	pkgconfig(gspell-1)
BuildRequires:	pkgconfig(json-glib-1.0)
BuildRequires:	pkgconfig(libsecret-1)
BuildRequires:	pkgconfig(flatpak) >= %{flatpak_version}
BuildRequires:	sysprof-devel
BuildRequires:	pkgconfig(valgrind)
BuildRequires:	pkgconfig(rpm)
BuildRequires:	pkgconfig(xmlb)
BuildRequires:	pkgconfig(goa-1.0)
BuildRequires:	pkgconfig(gudev-1.0)
BuildRequires:	pkgconfig(oauth)
BuildRequires:	gnome-common
BuildRequires:	meson
Requires:	adwaita-icon-theme
Requires:	fwupd%{?_isa} >= %{fwupd_version}
Requires:	gnome-packagekit
Requires:	flatpak%{?_isa} >= %{flatpak_version}

Obsoletes: gnome-software-editor < 3.35.1

%description
gnome-software is an application that makes it easy to add, remove
and update software in the GNOME desktop.

%package devel
Summary: Headers for building external gnome-software plugins
Group:	Development/GNOME and GTK+
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
These development files are for building gnome-software plugins outside
the source tree. Most users do not need this subpackage installed.

%prep
%autosetup -p1

%build
%meson		\
	-Dmalcontent=true \
	-Denable-polkit=true \
	-Denable-gnome-desktop=true \
	-Denable-packagekit=true \
	-Denable-flatpak=true \
	-Denable-ostree=true \
	-Denable-rpm=true \
	-Denable-shell-extensions=true \
	-Denable-gudev=true \
	-Denable-webapps=true
%meson_build

%install
export LANG=UTF-8
%meson_install

desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop

# remove unneeded static library
rm %{buildroot}%{_libdir}/libgnomesoftware.a

# make the software center load faster
desktop-file-edit %{buildroot}%{_datadir}/applications/org.gnome.Software.desktop \
    --set-key=X-AppInstall-Package --set-value=%{name}

# set up for Mageia
cat >> %{buildroot}%{_datadir}/glib-2.0/schemas/org.gnome.software-mageia.gschema.override << FOE
[org.gnome.software]
official-repos = [ 'mageia-*', 'cauldron-*', 'updates-*', 'updates_testing-*', 'backports-*', 'backports_testing-*' ]
FOE

%find_lang %name --with-gnome

%check
#meson_test

%files -f %{name}.lang
%license COPYING
%doc AUTHORS README.md
%{_bindir}/%{name}
%{_datadir}/applications/*.desktop
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/*.png
%{_datadir}/gnome-software/featured-*.svg
%{_datadir}/gnome-software/featured-*.jpg
%{_mandir}/man1/%{name}.1.*
%{_iconsdir}/*/*/apps/*
%{_iconsdir}/hicolor/scalable/status/software-installed-symbolic.svg
%{_sysconfdir}/xdg/autostart/%{name}-service.desktop
%{_datadir}/app-info/xmls/org.gnome.Software.Featured.xml
%{_datadir}/dbus-1/services/org.freedesktop.PackageKit.service
%{_datadir}/dbus-1/services/org.gnome.Software.service
%{_datadir}/glib-2.0/schemas/org.gnome.software.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.software-mageia.gschema.override
%{_datadir}/gnome-shell/search-providers/*-search-provider.ini
%dir %{_libdir}/gs-plugins-*/
%{_libdir}/gs-plugins-*/*.so*
%{_libexecdir}/gnome-software-cmd
%{_libexecdir}/gnome-software-restarter
%{_datadir}/metainfo/org.gnome.Software.appdata.xml
%{_datadir}/metainfo/org.gnome.Software.Plugin.Flatpak.metainfo.xml
%{_datadir}/metainfo/org.gnome.Software.Plugin.Fwupd.metainfo.xml
%{_datadir}/metainfo/org.gnome.Software.Plugin.Odrs.metainfo.xml

%files devel
%{_libdir}/pkgconfig/gnome-software.pc
%dir %{_includedir}/gnome-software
%{_includedir}/gnome-software/*.h
%{_datadir}/gtk-doc/html/gnome-software


%changelog
* Tue Jan 26 2021 neoclust <neoclust> 3.38.0-2.mga8
+ Revision: 1673524
- Rebuild against new flatpak

* Fri Sep 11 2020 ovitters <ovitters> 3.38.0-1.mga8
+ Revision: 1624532
- new version 3.38.0

* Mon Sep 07 2020 tv <tv> 3.37.92-1.mga8
+ Revision: 1623248
- 3.37.92

* Sat Aug 29 2020 tv <tv> 3.36.1-6.mga8
+ Revision: 1619687
- rebuild for new libxmlb

* Tue Aug 18 2020 ovitters <ovitters> 3.36.1-5.mga8
+ Revision: 1614781
- rebuild for flatpak

* Sun Aug 16 2020 ovitters <ovitters> 3.36.1-4.mga8
+ Revision: 1614178
- really enable malcontent
- enable malcontent support

* Thu Jul 23 2020 ovitters <ovitters> 3.36.1-2.mga8
+ Revision: 1608138
- add Fedora trick to make it load quicker

* Fri May 22 2020 ovitters <ovitters> 3.36.1-1.mga8
+ Revision: 1586848
- new version 3.36.1

* Wed Mar 11 2020 ovitters <ovitters> 3.36.0-1.mga8
+ Revision: 1555567
- new version 3.36.0

* Wed Mar 04 2020 ovitters <ovitters> 3.35.92-1.mga8
+ Revision: 1553656
- new version 3.35.92
- dropped merged patch 0001-Fix-crash-when-viewing-application-details.patch

* Sat Feb 29 2020 tv <tv> 3.35.91-1.mga8
+ Revision: 1552359
- new version
- drop editor subpkg
- fix crash
+ ovitters <ovitters>
- new version 3.35.91

* Tue Feb 18 2020 umeabot <umeabot> 3.34.2-2.mga8
+ Revision: 1538638
- Mageia 8 Mass Rebuild

* Mon Nov 25 2019 ovitters <ovitters> 3.34.2-1.mga8
+ Revision: 1462730
- new version 3.34.2

* Mon Oct 07 2019 ovitters <ovitters> 3.34.1-1.mga8
+ Revision: 1450334
- new version 3.34.1

* Tue Sep 10 2019 tv <tv> 3.34.0-1.mga8
+ Revision: 1439272
- new release

* Thu Jul 11 2019 ovitters <ovitters> 3.32.4-1.mga8
+ Revision: 1420356
- new version 3.32.4

* Tue Jul 02 2019 ovitters <ovitters> 3.32.3-1.mga8
+ Revision: 1417612
- new version 3.32.3

* Sun Jun 16 2019 ngompa <ngompa> 3.32.2-2.mga7
+ Revision: 1400098
- Rebuild with updated flatpak

* Wed May 08 2019 tmb <tmb> 3.32.2-1.mga7
+ Revision: 1396783
- update to 3.32.2

* Wed Apr 17 2019 umeabot <umeabot> 3.32.1-2.mga7
+ Revision: 1392468
- Rebuild with meson 0.50.1

* Tue Apr 16 2019 ovitters <ovitters> 3.32.1-1.mga7
+ Revision: 1391081
- new version 3.32.1
- dropped merged patch 0001-app-row-Add-shadow-to-app-icons.patch
- dropped merged patch 0001-Add-drop-shadows-to-icons-in-app-tiles-as-well.patch
- dropped merged patch 0001-folders-Add-nm-connection-editor.desktop-to-Utilitie.patch

* Sat Mar 16 2019 daviddavid <daviddavid> 3.32.0-3.mga7
+ Revision: 1377764
- backport upstream patch to add nm-connection-editor.desktop to Utilities folder
- backport one more upstream patch to add shadows to app icons

* Tue Mar 12 2019 daviddavid <daviddavid> 3.32.0-2.mga7
+ Revision: 1374963
- backport a patch to add shadows to app icons

* Tue Mar 12 2019 ovitters <ovitters> 3.32.0-1.mga7
+ Revision: 1374423
- new version 3.32.0

* Thu Mar 07 2019 ovitters <ovitters> 3.31.92-1.mga7
+ Revision: 1372565
- new version 3.31.92

* Thu Jan 31 2019 tv <tv> 3.30.6-2.mga7
+ Revision: 1362078
- enable fwupd support

* Tue Dec 18 2018 ovitters <ovitters> 3.30.6-1.mga7
+ Revision: 1342498
- new version 3.30.6

* Wed Oct 24 2018 ovitters <ovitters> 3.30.5-1.mga7
+ Revision: 1324965
- new version 3.30.5

* Wed Oct 24 2018 ovitters <ovitters> 3.30.4-1.mga7
+ Revision: 1324960
- new version 3.30.4

* Thu Oct 18 2018 ovitters <ovitters> 3.30.3-1.mga7
+ Revision: 1321992
- new version 3.30.3

* Fri Oct 05 2018 ovitters <ovitters> 3.30.2-1.mga7
+ Revision: 1318010
- new version 3.30.2

* Tue Sep 25 2018 ovitters <ovitters> 3.30.1-1.mga7
+ Revision: 1304846
- new version 3.30.1

* Tue Sep 04 2018 ovitters <ovitters> 3.30.0-1.mga7
+ Revision: 1257129
- new version 3.30.0

* Tue Sep 04 2018 tv <tv> 3.29.92-1.mga7
+ Revision: 1257091
- fix disabling fwupd"
+ ovitters <ovitters>
- new version 3.29.92

* Wed May 09 2018 ovitters <ovitters> 3.29.1-1.mga7
+ Revision: 1227944
- new version 3.29.1

* Wed May 09 2018 ovitters <ovitters> 3.28.2-1.mga7
+ Revision: 1227896
- new version 3.28.2

* Tue Apr 10 2018 ovitters <ovitters> 3.28.1-2.mga7
+ Revision: 1217301
- update gschema override

* Mon Apr 09 2018 ovitters <ovitters> 3.28.1-1.mga7
+ Revision: 1216856
- new version 3.28.1

* Wed Mar 14 2018 tv <tv> 3.28.0-2.mga7
+ Revision: 1209216
- rebuild with latest gspell

* Tue Mar 13 2018 ovitters <ovitters> 3.28.0-1.mga7
+ Revision: 1208794
- new version 3.28.0

* Mon Mar 05 2018 ovitters <ovitters> 3.27.92-1.mga7
+ Revision: 1206786
- new version 3.27.92

* Fri Feb 16 2018 ovitters <ovitters> 3.27.90-1.mga7
+ Revision: 1201630
- new version 3.27.90

* Thu Feb 08 2018 ovitters <ovitters> 3.26.6-1.mga7
+ Revision: 1199734
- new version 3.26.6

* Mon Jan 08 2018 ovitters <ovitters> 3.26.5-1.mga7
+ Revision: 1191690
- new version 3.26.5

* Sun Dec 17 2017 ovitters <ovitters> 3.26.4-1.mga7
+ Revision: 1183056
- new version 3.26.4

* Tue Nov 21 2017 ovitters <ovitters> 3.26.3-1.mga7
+ Revision: 1178489
- new version 3.26.3

* Thu Nov 09 2017 ovitters <ovitters> 3.26.2-1.mga7
+ Revision: 1176671
- new version 3.26.2

* Mon Oct 02 2017 ovitters <ovitters> 3.26.1-1.mga7
+ Revision: 1162708
- new version 3.26.1

* Mon Sep 11 2017 ovitters <ovitters> 3.26.0-1.mga7
+ Revision: 1152806
- new version 3.26.0

* Sun Sep 10 2017 tv <tv> 3.25.91-4.mga7
+ Revision: 1152472
- remove bogus removal of plugin provides -- was not working
- split devel subpkg instead of ignoring files

* Sun Sep 10 2017 tv <tv> 3.25.91-3.mga7
+ Revision: 1152465
- adjust file list
- new editor subpkg
- switch to %%autosetup
- disable broken testsuite (needs X11 socket + schemas)
- "fix" build
- rebuild for new rpm
+ ovitters <ovitters>
- use meson
- new version 3.25.91

* Mon Jul 10 2017 ovitters <ovitters> 3.24.3-2.mga6
+ Revision: 1109641
- require flatpak (per dev@)
- require gnome-packagekit (mga#21212)

* Mon May 15 2017 ovitters <ovitters> 3.24.3-1.mga6
+ Revision: 1101727
- new version 3.24.3

* Mon May 08 2017 ovitters <ovitters> 3.24.2-1.mga6
+ Revision: 1099659
- new version 3.24.2

* Mon Apr 10 2017 ovitters <ovitters> 3.24.1-1.mga6
+ Revision: 1096264
- new version 3.24.1

* Wed Mar 22 2017 ovitters <ovitters> 3.24.0-1.mga6
+ Revision: 1094418
- disable tests
- new version 3.24.0

* Tue Mar 14 2017 ovitters <ovitters> 3.22.7-1.mga6
+ Revision: 1092520
- new version 3.22.7

* Wed Mar 08 2017 ovitters <ovitters> 3.22.6-1.mga6
+ Revision: 1089967
- new version 3.22.6

* Mon Jan 16 2017 ovitters <ovitters> 3.22.5-1.mga6
+ Revision: 1082043
- new version 3.22.5

* Thu Dec 08 2016 ovitters <ovitters> 3.22.4-1.mga6
+ Revision: 1073205
- new version 3.22.4

* Thu Dec 01 2016 ovitters <ovitters> 3.22.3-1.mga6
+ Revision: 1071465
- new version 3.22.3
- new version 3.22.2
- new version 3.22.1

* Sun Sep 25 2016 ovitters <ovitters> 3.22.0-2.mga6
+ Revision: 1056167
- enable support for flatpak, gudev, firmware, ostree
- new version 3.22.0

* Thu Jul 21 2016 ngompa <ngompa> 3.20.4-2.mga6
+ Revision: 1042981
- Simplify official-sources override for gnome-software

* Tue Jul 12 2016 ovitters <ovitters> 3.20.4-1.mga6
+ Revision: 1041426
- new version 3.20.4

* Sun Jun 26 2016 ngompa <ngompa> 3.20.3-1.mga6
+ Revision: 1037697
- Declare all Mageia repositories as official sources
- Add gschema override for GNOME Software for Mageia
+ ovitters <ovitters>
- new version 3.20.3
- new version 3.20.2

* Tue Apr 12 2016 ovitters <ovitters> 3.20.1-1.mga6
+ Revision: 1000884
- new version 3.20.1

* Mon Mar 21 2016 ovitters <ovitters> 3.20.0-1.mga6
+ Revision: 993511
- new version 3.20.0

* Fri Mar 18 2016 tv <tv> 3.19.92-1.mga6
+ Revision: 992758
- adjust file list
- adjust file list
- bump needed appstream-glib version
+ ovitters <ovitters>
- new version 3.19.92
- new version 3.19.91
- new version 3.19.90

* Mon Feb 15 2016 umeabot <umeabot> 3.18.3-2.mga6
+ Revision: 960466
- Mageia 6 Mass Rebuild

* Thu Nov 05 2015 ovitters <ovitters> 3.18.3-1.mga6
+ Revision: 897908
- new version 3.18.3

* Thu Oct 15 2015 ovitters <ovitters> 3.18.2-1.mga6
+ Revision: 891740
- new version 3.18.2

* Tue Oct 13 2015 ovitters <ovitters> 3.18.1-1.mga6
+ Revision: 890312
- new version 3.18.1

* Thu Sep 24 2015 tv <tv> 3.18.0-1.mga6
+ Revision: 883336
- update BR
- new release
+ ovitters <ovitters>
- new version 3.17.92

* Tue Sep 15 2015 fwang <fwang> 3.17.91-2.mga6
+ Revision: 879520
- update file list
- rebuild for new appstream
+ ovitters <ovitters>
- new version 3.17.91
- new version 3.17.90
- new version 3.16.5

* Mon Aug 03 2015 ovitters <ovitters> 3.14.7-1.mga6
+ Revision: 860888
- new version 3.14.7

* Fri Jul 24 2015 sander85 <sander85> 3.14.6-2.mga6
+ Revision: 856965
- Rebuild for new gnome-desktop3

* Sat Jun 20 2015 ovitters <ovitters> 3.14.6-1.mga6
+ Revision: 836436
- new version 3.14.6
- new version 3.14.2

* Wed Oct 15 2014 umeabot <umeabot> 3.14.1-2.mga5
+ Revision: 750806
- Second Mageia 5 Mass Rebuild

* Mon Oct 13 2014 ovitters <ovitters> 3.14.1-1.mga5
+ Revision: 738315
- new version 3.14.1

* Sun Sep 28 2014 wally <wally> 3.14.0-1.mga5
+ Revision: 731360
- new version 3.14.0
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild
+ ovitters <ovitters>
- new version 3.13.92

* Wed Sep 03 2014 ovitters <ovitters> 3.13.91-1.mga5
+ Revision: 671191
- new version 3.13.91

* Tue Aug 19 2014 fwang <fwang> 3.13.90-1.mga5
+ Revision: 665488
- update file list
- bump br
+ ovitters <ovitters>
- new version 3.13.90

* Mon Aug 11 2014 fwang <fwang> 3.13.4-2.mga5
+ Revision: 661623
- rebuild for new packagekit

* Tue Jul 29 2014 ovitters <ovitters> 3.13.4-1.mga5
+ Revision: 657920
- new version 3.13.4

* Tue Jun 24 2014 ovitters <ovitters> 3.13.3-1.mga5
+ Revision: 639430
- new version 3.13.3

* Wed May 28 2014 wally <wally> 3.13.2-1.mga5
+ Revision: 627269
- exclude plugin .so from provides
+ ovitters <ovitters>
- new version 3.13.2

* Mon May 12 2014 ovitters <ovitters> 3.12.2-1.mga5
+ Revision: 622159
- new version 3.12.2
+ wally <wally>
- require adwaita-icon-theme instead of obsolete gnome-icon-theme

* Fri Apr 11 2014 ovitters <ovitters> 3.12.1-1.mga5
+ Revision: 613454
- new version 3.12.1

* Mon Mar 24 2014 ovitters <ovitters> 3.12.0-1.mga5
+ Revision: 607830
- new version 3.12.0

* Thu Mar 20 2014 ovitters <ovitters> 3.11.92-1.mga5
+ Revision: 606208
- new version 3.11.92

* Fri Mar 14 2014 dams <dams> 3.11.91-1.mga5
+ Revision: 603452
- use autoreconf
+ ovitters <ovitters>
- new version 3.11.91
- new version 3.11.90

* Thu Feb 06 2014 dams <dams> 3.11.5-1.mga5
+ Revision: 584124
- new version 3.11.5

* Tue Nov 26 2013 ovitters <ovitters> 3.10.4-1.mga4
+ Revision: 553516
- new version 3.10.4

* Mon Oct 28 2013 ovitters <ovitters> 3.10.3-1.mga4
+ Revision: 547637
- new version 3.10.3

* Tue Oct 22 2013 umeabot <umeabot> 3.10.2-2.mga4
+ Revision: 542209
- Mageia 4 Mass Rebuild

* Fri Oct 18 2013 ovitters <ovitters> 3.10.2-1.mga4
+ Revision: 520415
- new version 3.10.2

* Mon Oct 14 2013 ovitters <ovitters> 3.10.1-1.mga4
+ Revision: 497094
- new version 3.10.1

* Wed Sep 25 2013 ovitters <ovitters> 3.10.0-1.mga4
+ Revision: 485754
- based on Fedora

